Fio 3.15
[fio.git] / zbd.h
diff --git a/zbd.h b/zbd.h
index 82ce4662834f17c07029a2b4fa8ce40a9ed96a5a..521283b200d0f6ceb24b699a901493e3381d55e9 100644 (file)
--- a/zbd.h
+++ b/zbd.h
@@ -8,6 +8,7 @@
 #define FIO_ZBD_H
 
 #include <inttypes.h>
+#include "fio.h"       /* FIO_MAX_OPEN_ZBD_ZONES */
 #ifdef CONFIG_LINUX_BLKZONED
 #include <linux/blkzoned.h>
 #endif
@@ -30,8 +31,8 @@ enum io_u_action {
 
 /**
  * struct fio_zone_info - information about a single ZBD zone
- * @start: zone start in 512 byte units
- * @wp: zone write pointer location in 512 byte units
+ * @start: zone start location (bytes)
+ * @wp: zone write pointer location (bytes)
  * @verify_block: number of blocks that have been verified for this zone
  * @mutex: protects the modifiable members in this structure
  * @type: zone type (BLK_ZONE_TYPE_*)
@@ -56,12 +57,18 @@ struct fio_zone_info {
 /**
  * zoned_block_device_info - zoned block device characteristics
  * @model: Device model.
* @mutex: Protects the modifiable members in this structure (refcount).
  * @zone_size: size of a single zone in units of 512 bytes
+ * @sectors_with_data: total size of data in all zones in units of 512 bytes
  * @zone_size_log2: log2 of the zone size in bytes if it is a power of 2 or 0
  *             if the zone size is not a power of 2.
  * @nr_zones: number of zones
  * @refcount: number of fio files that share this structure
+ * @num_open_zones: number of open zones
+ * @write_cnt: Number of writes since the latest zone reset triggered by
+ *            the zone_reset_frequency fio job parameter.
+ * @open_zones: zone numbers of open zones
  * @zone_info: description of the individual zones
  *
  * Only devices for which all zones have the same size are supported.
@@ -72,9 +79,13 @@ struct zoned_block_device_info {
        enum blk_zoned_model    model;
        pthread_mutex_t         mutex;
        uint64_t                zone_size;
+       uint64_t                sectors_with_data;
        uint32_t                zone_size_log2;
        uint32_t                nr_zones;
        uint32_t                refcount;
+       uint32_t                num_open_zones;
+       uint32_t                write_cnt;
+       uint32_t                open_zones[FIO_MAX_OPEN_ZBD_ZONES];
        struct fio_zone_info    zone_info[0];
 };
 
@@ -84,9 +95,25 @@ int zbd_init(struct thread_data *td);
 void zbd_file_reset(struct thread_data *td, struct fio_file *f);
 bool zbd_unaligned_write(int error_code);
 enum io_u_action zbd_adjust_block(struct thread_data *td, struct io_u *io_u);
-int zbd_do_trim(struct thread_data *td, const struct io_u *io_u);
-void zbd_update_wp(struct thread_data *td, const struct io_u *io_u);
 char *zbd_write_status(const struct thread_stat *ts);
+
+static inline void zbd_queue_io_u(struct io_u *io_u, enum fio_q_status status)
+{
+       if (io_u->zbd_queue_io) {
+               io_u->zbd_queue_io(io_u, status, io_u->error == 0);
+               io_u->zbd_queue_io = NULL;
+       }
+}
+
+static inline void zbd_put_io_u(struct io_u *io_u)
+{
+       if (io_u->zbd_put_io) {
+               io_u->zbd_put_io(io_u);
+               io_u->zbd_queue_io = NULL;
+               io_u->zbd_put_io = NULL;
+       }
+}
+
 #else
 static inline void zbd_free_zone_info(struct fio_file *f)
 {
@@ -112,20 +139,14 @@ static inline enum io_u_action zbd_adjust_block(struct thread_data *td,
        return io_u_accept;
 }
 
-static inline int zbd_do_trim(struct thread_data *td, const struct io_u *io_u)
-{
-       return 1;
-}
-
-static inline void zbd_update_wp(struct thread_data *td,
-                                const struct io_u *io_u)
-{
-}
-
 static inline char *zbd_write_status(const struct thread_stat *ts)
 {
        return NULL;
 }
+
+static inline void zbd_queue_io_u(struct io_u *io_u,
+                                 enum fio_q_status status) {}
+static inline void zbd_put_io_u(struct io_u *io_u) {}
 #endif
 
 #endif /* FIO_ZBD_H */
@@ -56,12 +57,18 @@ struct fio_zone_info {
  * zoned_block_device_info - zoned block device characteristics
  * @model: Device model.
- * @mutex: Protects the modifiable members in this structure (refcount).
+ * @mutex: Protects the modifiable members in this structure (refcount and
+ *             num_open_zones).
  * @zone_size: size of a single zone in units of 512 bytes